import React from 'react'
import { MinusCircleOutlined, PlusCircleOutlined } from '@ant-design/icons';
import { Button, Form, Input, Space, Select, message } from 'antd';
import { getDebugTable } from './request';

export default class DatasourceNodeInfo extends React.Component<any, any> {

  constructor(props: any) {
    super(props)
    this.state = {
      debugTable: []
    }
  }

  async componentDidMount(){
    const { data } = await getDebugTable({
      user_id: 'test',
      project_id: 'test'
    })
    if (data.code === 200) {
      this.setState({debugTable: data.data})
    } else {
      message.error('获取调试数据表失败')
    }
  }

  render() {
    return (
      <div className='node-datasource'>
        <Form
          name="datasourceInfo"
          autoComplete="off"
          initialValues={{
            inputDatasource: this.props.nodeInfo.inputSource,
            dataTable: this.props.nodeInfo.dataTable
          }}
          onValuesChange={(changedValue, values) => {
            const dataSource = values.inputDatasource?.filter((item: any) => {
              return item && item.dataField && item.dataType
            })
            this.props.nodeInfo.inputSource = dataSource
          }}
        >
          <p>输入源:</p>
          <Form.List name="inputDatasource">
            {(fields, { add, remove }) => (
              <>
                {fields.map(({ key, name, ...restField }) => (
                  <Space key={key} style={{ display: 'flex', margin: '10px 0 -20px'}} align="baseline">
                    <Form.Item
                      {...restField}
                      name={[name, 'dataField']}
                      rules={[{required: true, message: '请填写字段'}]}
                    >
                      <Input placeholder="字段名"/>
                    </Form.Item>
                    <Form.Item
                      {...restField}
                      name={[name, 'dataType']}
                      rules={[{required: true, message: '请填写字段类型'}]}
                    >
                      <Select options={[
                        {label: 'string', value: 'string'},
                        {label: 'int', value: 'int'},
                        {label: 'text', value: 'text'},
                        {label: 'float', value: 'float'},
                        {label: 'double', value: 'double'},
                      ]} placeholder='请选择字段类型'/>
                    </Form.Item>
                    <MinusCircleOutlined onClick={() => remove(name)}  style={{color:'#147BD1'}}/>
                  </Space>
                ))}
                <Form.Item>
                  <Button type="link" onClick={() => {
                    add()
                  }} icon={<PlusCircleOutlined />} style={{paddingLeft: 0, paddingRight: 0}}>
                    添加字段
                  </Button>
                </Form.Item>
              </>
            )}
          </Form.List>
          <p>添加调试数据表</p>
          <Form.Item name='dataTable' style={{width: '80%', marginTop: '5px'}}>
            <Select options={this.state.debugTable.map((item: any) => {
              return {label: item.name, value: item.id}
            })} placeholder='选择调试数据表' onSelect={(val: any) => {
              this.props.nodeInfo.dataTable = val
            }}/>
          </Form.Item>
        </Form>
      </div>
    )
  }
}